@@ -58,7 +58,8 @@ test_that("Order of dummy columns (e.g. 0,0,1,0) is right", {
   expect_equal(dummy_cols(fastDummies_example_tibble)$animals_cat, c(0, 0, 1))
   expect_equal(dummy_cols(fastDummies_example_tibble,
                           remove_first_dummy = TRUE)$animals_cat, c(0, 0, 1))
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "animals",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "animals",
                           remove_first_dummy = TRUE)$animals_cat, c(0, 0, 1))
 
 })
@@ -176,10 +177,12 @@ test_that("Order of non-dummy columns is same", {
   expect_equal(dummy_cols(fastDummies_example_tibble,
                           select_columns = "animals")$numbers,
                fastDummies_example_tibble$numbers)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "gender",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "gender",
                           remove_first_dummy = TRUE)$numbers,
                fastDummies_example_tibble$numbers)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "animals",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "animals",
                           remove_first_dummy = TRUE)$numbers,
                fastDummies_example_tibble$numbers)
 
@@ -190,9 +193,11 @@ test_that("Order of non-dummy columns is same", {
                           select_columns = "gender")$gender, gender_list)
   expect_equal(dummy_cols(fastDummies_example_tibble,
                           select_columns = "animals")$gender, gender_list)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "gender",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "gender",
                           remove_first_dummy = TRUE)$gender, gender_list)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "animals",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "animals",
                           remove_first_dummy = TRUE)$gender, gender_list)
 
   expect_equal(dummy_cols(fastDummies_example_tibble)$animals, animals_list)
@@ -202,8 +207,10 @@ test_that("Order of non-dummy columns is same", {
                           select_columns = "gender")$animals, animals_list)
   expect_equal(dummy_cols(fastDummies_example_tibble,
                           select_columns = "animals")$animals, animals_list)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "gender",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "gender",
                           remove_first_dummy = TRUE)$animals, animals_list)
-  expect_equal(dummy_cols(fastDummies_example_tibble, select_columns = "animals",
+  expect_equal(dummy_cols(fastDummies_example_tibble,
+                          select_columns = "animals",
                           remove_first_dummy = TRUE)$animals, animals_list)
 })
